slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPGetErrorEstimate

Returns the error estimate associated to the i-th computed eigenpair.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPGetErrorEstimate(NEP nep,PetscInt i,PetscReal *errest)

Not Collective

### Input Parameters

| nep | - nonlinear eigensolver context
| i | - index of eigenpair

### Output Parameter

| errest | - the error estimate

### Notes

This is the error estimate used internally by the eigensolver. The actual error bound can be computed with NEPComputeError().

### See Also

NEPComputeError()

### Level

advanced

### Location

src/nep/interface/nepsolve.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages